==> nextcloud-29.0.12.zip: nextcloud/apps/photos/l10n/hr.js <==
OC.L10N.register(
    "photos",
    {
    "Public link" : "Javna poveznica",
    "Photos" : "Fotografije",
    "Your memories under your control" : "Upravljajte svojim sjećanjima",
    "Videos" : "Videozapisi",
    "People" : "Ljudi",
    "Folders" : "Mape",
    "Favorites" : "Favoriti",
    "Shared with you" : "Podijeljeno s vama",
    "Tags" : "Oznake",
    "Back" : "Natrag",
    "Save" : "Spremi",
    "Shared by" : "Podijeljeno od",
    "No recommendations. Start typing." : "Nema preporuka. Započnite unos.",
    "Copy public link" : "Kopiraj javnu poveznicu",
    "An error occurred" : "Došlo je do pogreške",
    "Favorite" : "Favorit",
    "Open the full size \"{name}\" image" : "Otvori sliku „{name}” u punoj veličini",
    "Go back" : "Natrag",
    "Back to {folder}" : "Natrag na {folder}",
    "Share this folder" : "Dijeli ovu mapu",
    "Enable squared photos view" : "Omogući kvadratni prikaz fotografija",
    "Add folder" : "Dodaj mapu",
    "Home" : "Doma",
    "View" : "Pregledaj",
    "Remove from favorites" : "Ukloni iz favorita",
    "This folder does not exist" : "Ova mapa ne postoji",
    "No photos in here" : "Ovdje nema fotografija",
    "No tags yet" : "Još nema oznaka",
    "Photos with tags will show up here" : "Ovdje će se prikazivati fotografije s oznakama",
    "Delete selection" : "Izbriši odabir",
    "Tagged photos" : "Označene fotografije",
    "Details" : "Pojedinosti",
    "Add" : "Dodaj"
},
"nplurals=3; plural=n%10==1 && n%100!=11 ? 0 : n%10>=2 && n%10<=4 && (n%100<10 || n%100>=20) ? 1 : 2;");

==> nextcloud-33.0.0rc2.zip: nextcloud/apps/photos/l10n/hr.js <==
OC.L10N.register(
    "photos",
    {
    "Public link" : "Javna poveznica",
    "Photos" : "Fotografije",
    "Your memories under your control" : "Upravljajte svojim sjećanjima",
    "Videos" : "Videozapisi",
    "People" : "Ljudi",
    "Folders" : "Mape",
    "Favorites" : "Favoriti",
    "Shared with you" : "Podijeljeno s vama",
    "Tags" : "Oznake",
    "Places" : "Mjesta",
    "This name is already in use." : "Ovaj naziv se već koristi",
    "\"{char}\" is not allowed inside a filename." : "\"{char}\" nije dopušteno unutar naziva datoteke.",
    "Invalid filename." : "Nevažeći naziv datoteke.",
    "Back" : "Natrag",
    "Save" : "Spremi",
    "Shared by" : "Podijeljeno od",
    "No recommendations. Start typing." : "Nema preporuka. Započnite unos.",
    "Copy public link" : "Kopiraj javnu poveznicu",
    "An error occurred" : "Došlo je do pogreške",
    "Favorite" : "Favorit",
    "Open the full size \"{name}\" image" : "Otvori sliku „{name}” u punoj veličini",
    "Go back" : "Natrag",
    "All folders" : "Sve mape",
    "Add folder" : "Dodaj mapu",
    "Home" : "Doma",
    "General" : "Općenito",
    "Unselect all" : "Odznači sve",
    "Remove from favorites" : "Ukloni iz favorita",
    "This folder does not exist" : "Ova mapa ne postoji",
    "No photos in here" : "Ovdje nema fotografija",
    "No tags yet" : "Još nema oznaka",
    "Photos with tags will show up here" : "Ovdje će se prikazivati fotografije s oznakama",
    "Delete selection" : "Izbriši odabir",
    "Tagged photos" : "Označene fotografije",
    "Last week" : "Prošli tjedan",
    "Details" : "Pojedinosti",
    "Cancel" : "Cancel",
    "Confirm" : "Potvrdi",
    "Back to {folder}" : "Natrag na {folder}",
    "Share this folder" : "Dijeli ovu mapu",
    "Enable squared photos view" : "Omogući kvadratni prikaz fotografija",
    "View" : "Pregledaj",
    "Add" : "Dodaj"
},
"nplurals=3; plural=n%10==1 && n%100!=11 ? 0 : n%10>=2 && n%10<=4 && (n%100<10 || n%100>=20) ? 1 : 2;");
